import React, { FC } from 'react';
import { View } from 'react-native';
import { GradualShutterWidgetDetailModel } from '../../widgetDetailModels';
import { ShutterControlPanel } from '../components/shutterControlPanel';
import { ShutterQuickActions } from '../components/shutterQuickActions';
import { ShutterAction } from '../components/shutterModels';
import { useShutter } from '../hooks/useShutter';

const getNumberFromValue = (value: string) => Number(value);
const getStringFromActionResult = (result: number) => String(result);

export const GradualShutterWidgetDetail: FC<GradualShutterWidgetDetailModel> = ({
  id,
  widgetName,
  widgetInfoTextOptions,
  loadingInfoTextOptions,
  quickActionsTitle,
  quickActionButtonsTextOptions,
  controlPanelTitle,
  value = '0',
  onUpdateData,
  loading = false,
}) => {
  const { shutterOutputValue, onShutterAction, shutterOngoingAction } = useShutter(getNumberFromValue(value));
  const buttonOneText = quickActionButtonsTextOptions?.open;
  const buttonTwoText = quickActionButtonsTextOptions?.close;

  const onChangeShutterValue = (action: ShutterAction) => {
    const resultAfterAction = onShutterAction(action);
    onUpdateData?.({ id, value: getStringFromActionResult(resultAfterAction) });
  };

  return (
    <View>
      <ShutterQuickActions
        title={quickActionsTitle}
        value={shutterOutputValue}
        buttonOneText={buttonOneText}
        buttonTwoText={buttonTwoText}
        onClick={onChangeShutterValue}
        loading={loading}
      />
      <ShutterControlPanel
        title={controlPanelTitle}
        widgetName={widgetName}
        widgetStateInfoOptions={widgetInfoTextOptions}
        loadingInfoTextOptions={loadingInfoTextOptions}
        value={shutterOutputValue}
        ongoingAction={shutterOngoingAction}
        onClick={onChangeShutterValue}
        loading={loading}
      />
    </View>
  );
};
