import type { DateNumberOfTheMonth, MonthNumber } from './calendarModel';

const JANUARY: MonthNumber = 1;
const DECEMBER: MonthNumber = 12;

interface DaysOfMonth { 
  datesOfPreviousToMonth: DateNumberOfTheMonth;
  datesOfCurrentToMonth: DateNumberOfTheMonth;
  datesOfNextToMonth: DateNumberOfTheMonth;
}

type GetDatesOfSelectedMonth = (month: MonthNumber, year: number) => DaysOfMonth;

export const getDatesOfSelectedMonth: GetDatesOfSelectedMonth = (month, year) => {
  const previousYear = month === JANUARY ? year - 1 : year;
  const nextYear = month === DECEMBER ? year + 1 : year;

  const previousMonth = month === JANUARY ? DECEMBER : month - 1;
  const nextMonth = month === DECEMBER ? JANUARY : month + 1;

  const datesOfPreviousToMonth = new Date(previousYear, previousMonth, 1).getUTCDate() as DateNumberOfTheMonth;
  const datesOfCurrentToMonth = new Date(year, month, 1).getUTCDate()  as DateNumberOfTheMonth;
  const datesOfNextToMonth = new Date(nextYear, nextMonth, 1).getUTCDate()  as DateNumberOfTheMonth;

  return {
    datesOfPreviousToMonth,
    datesOfCurrentToMonth,
    datesOfNextToMonth,
  };
};
